package Plugins::InfoBrowserAddons::TvGuideCoUk::TvGuideCoUk;

use strict;

use Slim::Formats::XML;
use Slim::Networking::Async::HTTP;
use HTTP::Request;

# To customise the channels shown access www.tvguide.co.uk via your browser and go to the 'select channels' button
# Then find the value of the UserID cookie stored in your browser for 'tvguide.co.uk' and add it below:
my $UserID = 702728;

my $needInit = 1;

sub parse {
	my $class  = shift;
	my $http   = shift;

	my $params = $http->params('params');
	my $url = $params->{'url'};

	my @list;
	my $current;

	my $parser = HTML::Parser->new(api_version => 3,
		start_h => [
			sub {
				my $tag  = shift;
				my $attr = shift;

				if ($tag eq 'a' && $attr->{'href'} && $attr->{'href'} =~ /channellisting/) {

					my ($channel) = $attr->{'title'} =~ /header=\[Click for (.*) full day TV listings\]/;

					$current = [];
					push @list, {
						'name'  => $channel,
						'items' => $current,
					};

				} elsif ($tag eq 'a' && $attr->{'class'} eq 'title') {

					my ($header, $body) = $attr->{'title'} =~ /header=\[(.*)\] body=\[(.*)\]/;

					$header =~ s/(\d+):(\d+)am-\d+:\d+[ap]m/sprintf("%02d:%02d", $1 < 12 ? $1 : $1 - 12, $2)/e;
					$header =~ s/(\d+):(\d+)pm-\d+:\d+[ap]m/sprintf("%02d:%02d", $1 < 12 ? 12+$1 : $1, $2)/e;

					$body =~ s/<.*?>//g;
					$body =~ s/\(subtitles\)//;
					$body =~ s/\s*Click for more info.*//;
					$body =~ s/\s*Click to be the first to rate this show.*//;
					$body =~ s/^\s*//;

					push @{$current}, {
						'name'        => $header,
						'title'       => $header,
						'description' => $body,
					};
				}

			}, "tagname,attr"
		]
	);

	if ($needInit && $UserID) {
		# create dummy request to see if we have UserID cookie, otherwise set it in the cookie jar

		my $cookieJar = Slim::Networking::Async::HTTP->cookie_jar;
		my $req       = $cookieJar->add_cookie_header(HTTP::Request->new(GET => $url));

		if ($req->header('cookie') !~ /UserID/) {
			$cookieJar->set_cookie(0, 'UserID', $UserID, '/', 'tvguide.co.uk', undef, undef, undef, 60*60*24*365);
			$cookieJar->set_cookie(0, 'gridspan', '06%3A00', '/', 'tvguide.co.uk', undef, undef, undef, 60*60*24*365);
		}

		$needInit = 0;

		return {
			'type' => 'redirect',
			'url'  => $url,
		};
	}

	$parser->parse($http->content);

	return {
		'type'      => 'opml',
		'title'     => $params->{'feedTitle'},
		'items'     => \@list,
		'cachetime' => 300,
	};
}

1;
